var ZeedhiDirectives = angular.module("ZeedhiDirectives");

ZeedhiDirectives.directive("zhRelations", function() {
	return {
		restrict: 'A',
		link: function($scope, $element) {

			var widget = $scope.widget;

			$scope.currentKey = null;
			$scope.keys = widget.parentsDataSource.data;
			$scope.values = widget.childsDataSource.data;
			$scope.relations = widget.relationsDataSource.data;

			$scope.keysValueField = widget.parentsValueField;
			$scope.valuesValueField = widget.childsValueField;

			$scope.keysDescriptionField = widget.parentsDescriptionField;
			$scope.valuesDescriptionField = widget.childsDescriptionField;

			$scope.relations.forEach(function(relation) {
				var relationChild = $scope.values.find(function(child) {
					return child[widget.childsValueField] == relation[widget.relationChildsField];
				});

				if (relationChild) {
					relationChild.__related = true;
				}
			});

			$scope.startRelating = function(selectedKey) {

				if (selectedKey === null) {

					$scope.currentKey.__related = false;
					$scope.currentKey = null;
					$scope.currentValues = [];

				} else {

					if ($scope.currentKey) {
						$scope.currentKey.__related = false;
					}

					$scope.currentKey = selectedKey;
					$scope.currentKey.__related = true;

					$scope.currentValues = $scope.getRelatedValues(selectedKey)
						.map(function(relation) {
							relation.__related = true;
							return relation;
						})
						.concat(
							$scope.values.filter(function(value) {
								return !value.__related;
							})
						);
				}
			};

			$scope.relateToCurrentKey = function(selectedValue) {
				// If there is already a relation with that child, remove it.
				var relation, removedChildFromParent = false;
				for (var i = $scope.relations.length - 1; i >= 0; i--) {
					relation = $scope.relations[i];
					if (relation[widget.relationChildsField] == selectedValue[widget.childsValueField]) {
						removedChildFromParent = true;
						$scope.relations.splice(i, 1);
						selectedValue.__related = false;
					}
				}

				// If there was no relation with the selected child, relate it with the current parent.
				if (!removedChildFromParent) {
					relation = {};
					relation[widget.relationParentsField] = $scope.currentKey[widget.parentsValueField];
					relation[widget.relationChildsField] = selectedValue[widget.childsValueField];
					$scope.relations.push(relation);
					selectedValue.__related = true;
				}
			};

			$scope.clearRelatedKeys = function(selectedKey) {
				$scope.getRelatedValues(selectedKey).forEach(function(item) {
					item.__related = false;
				});

				var relation;
				for (var i = $scope.relations.length - 1; i >= 0; i--) {
					relation = $scope.relations[i];
					if (relation[widget.relationParentsField] == selectedKey[widget.parentsValueField]) {
						$scope.relations.splice(i, 1);
					}
				}
			};

			$scope.getRelatedValues = function(key) {
				return $scope.relations.filter(function(relation) {
					return relation[widget.relationParentsField] == key[widget.parentsValueField];
				}).map(function(relation) {
					return $scope.values.find(function(child) {
						return relation[widget.relationChildsField] == child[widget.childsValueField];
					});
				});
			};

			$scope.resetUnselectedChildren = function() {
				$scope.values.filter(function(child) {
					return child.__related && $scope.relations.every(function(relation){
						return relation[widget.relationChildsField] != child[widget.childsValueField];
					});
				}).forEach(function(child) {
					child.__related = false;
				});
			};

			$scope.$watchCollection("relations", function(newValue) {
				widget.relationsDataSource.data = newValue;
			});

			$scope.$watchCollection("widget.relationsDataSource.data", function(newValue) {
				$scope.relations = newValue;
				$scope.resetUnselectedChildren();
			});

			$scope.$watchCollection("widget.parentsDataSource.data", function(newValue) {
				$scope.keys = widget.parentsDataSource.data;
			});

			$scope.$watchCollection("widget.childsDataSource.data", function(newValue) {
				$scope.values = widget.childsDataSource.data;
			});

		}
	};
});